# eric7.WebBrowser.WebBrowserSnap

Module implementing functions to generate page previews.

### Global Attributes

None

### Classes

None

### Functions

__render | Private function to render a pixmap of given size for a web page.
renderTabPreview | Public function to render a pixmap of a page.

## __render

__render(view, w, h)

Private function to render a pixmap of given size for a web page.

view
  reference to the view to be previewed (QWebEngineView)
w
  width of the pixmap (integer)
h
  height of the pixmap (integer)

Return:
  rendered pixmap (QPixmap)

Up

## renderTabPreview

renderTabPreview(view, w, h)

Public function to render a pixmap of a page.

view
  reference to the view to be previewed (QWebEngineView)
w
  width of the preview pixmap (integer)
h
  height of the preview pixmap (integer)

Return:
  preview pixmap (QPixmap)

Up